@@ -183,9 +183,15 @@ class AccountResource(Resource):
 
     def get_details(self, _id: str) -> AccountDetail:
         return super(AccountResource, self)._get_with_sub_path('{_id}/details'.format(_id=_id))
-    
+
     def enroll_auto_syncs(self, _id: str) -> Account:
         return super(AccountResource, self)._create_with_sub_path('{_id}/sync_enrollment'.format(_id=_id), {})
 
     def unenroll_auto_syncs(self, _id: str) -> Account:
         return super(AccountResource, self)._delete_with_sub_path('{_id}/sync_enrollment'.format(_id=_id))
+
+    def withdraw_consent(self, _id: str) -> Account:
+        return super(AccountResource, self)._create_with_sub_path(
+            '{_id}/consent'.format(_id=_id),
+            { 'type': 'withdraw', 'reason': 'holder_withdrew_consent' }
+        )
